<?php
/*
 * Classe créée par Olivier Hondermarck - toutjavascript.com
 * V1 - 2020
 * 
 * Les résultats sont non garantis et donnés à titre purement informatifs
 * Classe testée sur Linux Debian et Ubuntu
 * Classe testée sur Apache et NGINX
 *
 */	
	
class phpHardwareInfo {	
	
	protected function TJS_pluriel($val) {
		return $val > 1 ? "s" : "";
	}
	
	/* Format un délai entre 2 dates */
	protected function TJS_interval_format($interval) {				
		$format =$interval->y==0?"":" ".$interval->y." an".($interval->y>1?"s":"");
		$format.=$interval->m==0?"":" ".$interval->m." mois";
		$format.=$interval->d==0?"":" ".$interval->d." jour".($interval->d>1?"s":"");
		$format.=$interval->h==0?"":" ".$interval->h." heure".($interval->h>1?"s":"");
		$format.=$interval->i==0?"":" ".$interval->i." minute".($interval->i>1?"s":"");
		$format.=$interval->s==0?"":" ".$interval->s." seconde".($interval->s>1?"s":"");
		return trim($format);			
	}
	
	/* Formate des nombres en octets */
	protected function TJS_ram_format($n) {
		if ($n>=1024*1024*1023) {
			return number_format($n/1024/1024/1024, 2, ",", " ")." Go";
		}
		if ($n>=1024*1023) {
			return number_format($n/1024/1024, 2, ",", " ")." Mo";
		}
		if ($n>=1023) {
			return number_format($n/1024, 2, ",", " ")." ko";
		}
		return number_format($n, 0)." ko";		
	}
	
	
	/* Retourne une chaîne de caractères contenant l'OS et la version */
	/* Exemples :
			Debian 10.3 
	*/	
	public function getOS() {		
		$OS = file_get_contents("/etc/issue");
		$OS = trim(substr($OS, 0, strpos($OS, " ")));
		$release = $this->getRelease($OS);
		return "Linux ".$OS." ".$release;
	}
	
	/* Recherche la version (release) de l'OS */
	protected function getRelease($OS) {
		if ($OS=="Debian") {
			$release = file_get_contents("/etc/debian_version");	
		} else {
		   $release = exec("lsb_release -r"); 	
		   $release = str_replace("Release:", "", $release);
		}		
	   return trim($release);
	}
	
	
	/* Retourne la durée d'uptime */
	public function getUptime() {
		$uptime = exec("uptime -s"); 	
		$dtUptime=date_create($uptime);
		$now=date_create(date("Y-m-d H:i:s"));		
		$interval = date_diff($now, $dtUptime);
		return $this->TJS_interval_format($interval);
	}
	
	/* Retourne le nom du CPU */
	public function getCPU() {
		$cpuinfo = file_get_contents("/proc/cpuinfo");		
		preg_match_all('/(model name[ \t]*:)(.+)/',  $cpuinfo,  $matches);
		$cpu="CPU non reconnu";
		if ($matches[2]) {
			if ($matches[2][0]) {
				$cpu=trim($matches[2][0]);
				$cpu=str_replace("(R)", "", $cpu); 
				$cpu=str_replace("(TM)", "", $cpu); 
			}
		}
	
		return $cpu;
	}
	
	/* Retourne le logo du CPU selon la marque */
	public function getLogoCPU() {
		$cpu=$this->getCPU();
		if (strpos($cpu, "Intel") !== false) {
			return "<img class=\"marque\" src=\"media/intel.png\">";
		}
		if (strpos($cpu, "AMD") !== false) {
			return "<img class=\"marque\" src=\"media/intel.png\">";
		}
		return "";
	}
	
	
	/* Retourne le nombre de vCPU disponibles */
	public function getNbCPU() {
		$cpuinfo = file_get_contents("/proc/cpuinfo");		
		preg_match_all('/(model name[ \t]*:)(.+)/',  $cpuinfo,  $matches);		
		return sizeof($matches[1]);
	}
	
	
	/* Retourne un tableau d'informations concernant la RAM */
	public function getInfoRAM() {
		$RAM=Array();
		$meminfo = file_get_contents("/proc/meminfo");	
		
		
		preg_match_all('/(MemTotal:[ \t]+)([0-9]+)( kB)/',  $meminfo,  $matches);
		$MemTotal = intval($matches[2][0])*1024;
		$RAM["MemTotal"] = $this->TJS_ram_format($MemTotal);
		
		preg_match_all('/(MemAvailable:[ \t]+)([0-9]+)( kB)/',  $meminfo,  $matches);
		$MemFree = intval($matches[2][0])*1024;
		$RAM["MemFree"] = $this->TJS_ram_format($MemFree);

		$RAM["MemFreePct"] = round($MemFree / $MemTotal * 100);

		preg_match_all('/(SwapTotal:[ \t]+)([0-9]+)( kB)/',  $meminfo,  $matches);
		$SwapTotal = intval($matches[2][0])*1024;
		$RAM["SwapTotal"] = $this->TJS_ram_format($SwapTotal);
		
		preg_match_all('/(SwapFree:[ \t]+)([0-9]+)( kB)/',  $meminfo,  $matches);
		$SwapFree = intval($matches[2][0])*1024;
		$RAM["SwapFree"] = $this->TJS_ram_format($SwapFree);

		$RAM["SwapFreePct"] = round($SwapFree / $SwapTotal * 100);
		
		return $RAM;
	}
}
	
	
?>